### Name: bgcorrect
### Title: Background Correction
### Aliases: bgcorrect bgcorrect.gc bgcorrect.mas4 bgcorrect.mas5
###   bgcorrect.rma xpsBgCorrect-methods xpsBgCorrect
### Keywords: manip

### ** Examples

## first, load ROOT scheme file and ROOT data file
scheme.test3 <- root.scheme(paste(.path.package("xps"),"schemes/SchemeTest3.root",sep="/"))
data.test3 <- root.data(scheme.test3, paste(.path.package("xps"),"rootdata/DataTest3_cel.root",sep="/"))

## MAS4 sector background
data.bg.mas4 <- bgcorrect.mas4(data.test3,"tmp_Test3MAS4Bgrd",filedir=getwd(),tmpdir="",verbose=FALSE)

## need to attach background intensities
data.bg.mas4 <- attachBgrd(data.bg.mas4)

## get data.frame
bg.mas4 <- validBgrd(data.bg.mas4)
head(bg.mas4)

## plot images
if (interactive()) {
image.dev(data.bg.mas4,bg=TRUE,col=rainbow(32))
image(matrix(bg.mas4[,1], ncol=ncols(schemeSet(data.bg.mas4)), nrow=nrows(schemeSet(data.bg.mas4))))
}

## Not run: 
##D ## examples using Affymetrix human tissue dataset (see also xps/examples/script4exon.R)
##D 
##D ## example - exon array, e.g. HuEx-1_0-st-v2:
##D scmdir <- "/Volumes/GigaDrive/CRAN/Workspaces/Schemes"
##D datdir <- "/Volumes/GigaDrive/CRAN/Workspaces/ROOTData"
##D scheme.exon <- root.scheme(paste(scmdir,"Scheme_HuEx10stv2r2_na25.root",sep="/"))
##D data.exon   <- root.data(scheme.exon, paste(datdir,"HuTissuesExon_cel.root",sep="/"))
##D 
##D ## compute rma background
##D workdir <- "/Volumes/GigaDrive/CRAN/Workspaces/Exon/hutissues/exon"
##D data.bg.rma <- bgcorrect(data.exon, "HuExonRMABgrd", filedir=workdir, tmpdir="", 
##D                method="rma", select="antigenomic", option="pmonly:epanechnikov",
##D                params=c(16384), exonlevel="metacore+affx")
##D 
##D # or alternatively:
##D data.bg.rma <- bgcorrect.rma(data.exon, "HuExonRMABgrd", filedir=workdir, tmpdir="", 
##D                select="antigenomic", exonlevel="metacore+affx")
## End(Not run)



